pygeai.tests.snippets.assistants package
========================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pygeai.tests.snippets.assistants.data_analyst
   pygeai.tests.snippets.assistants.rag

Submodules
----------

pygeai.tests.snippets.assistants.create\_chat\_assistant module
---------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.assistants.create_chat_assistant
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.assistants.create\_text\_assistant module
---------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.assistants.create_text_assistant
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.assistants.file\_summarizer\_assistant module
-------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.assistants.file_summarizer_assistant
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.assistants.get\_assistant\_data module
------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.assistants.get_assistant_data
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.assistants.get\_assistant\_list module
------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.assistants.get_assistant_list
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.assistants.send\_feedback module
------------------------------------------------------

.. automodule:: pygeai.tests.snippets.assistants.send_feedback
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.assistants.update\_chat\_assistant module
---------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.assistants.update_chat_assistant
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: pygeai.tests.snippets.assistants
   :members:
   :show-inheritance:
   :undoc-members:
